<?php

namespace Drupal\index_now\Service;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\State\StateInterface;

/**
 * Key generator service.
 */
final class IndexNowKeyManager implements IndexNowKeyManagerInterface {

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The Uuid service.
   *
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected $uuid;

  /**
   * Key Generator constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   *   The uuid service.
   */
  public function __construct(
    StateInterface $state,
    UuidInterface $uuid
  ) {
    $this->state = $state;
    $this->uuid = $uuid;
  }

  /**
   * {@inheritdoc}
   */
  public function generateKey() {
    // Generate a random API key.
    $api_key = $this->uuid->generate();

    // Store the API key.
    $this->state->set(self::INDEXNOW_KEY_STATE_ID, $api_key);
  }

  /**
   * {@inheritdoc}
   */
  public function getKey() : string {
    return $this->state->get(self::INDEXNOW_KEY_STATE_ID) ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() : array {
    return [
      'state:' . self::INDEXNOW_KEY_STATE_ID,
    ];
  }

}
